@@ -1,27 +1,3 @@
-/***************************************************************************
-                             SRC/NEWMAT/newmat.h  description
-                             ------------------------
-    copyright            : (C) MIXMOD Team - 2001-2003-2004-2005-2006-2007-2008-2009
-    email                : mixmod@univ-fcomte.fr
- ***************************************************************************/
-
-/***************************************************************************
-    This file is part of MIXMOD
-    
-    MIXMOD is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    MIXMOD is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.     
-                                                                          
- ***************************************************************************/
 //$$ newmat.h           definition file for new version of matrix package
 
 // Copyright (C) 1991,2,3,4,7,2000,2002: R B Davies
